==> cutetube_1.7.0.tar.gz: cutetube-1.7.0/cutetubeapp/src/maemo5_gui/playbackqualitydialog.cpp <==
#include "playbackqualitydialog.h"
#include "separatorlabel.h"
#include "../base/settings.h"
#include <QCheckBox>
#include <QGridLayout>
#include <QDialogButtonBox>
#include <QScrollArea>

PlaybackQualityDialog::PlaybackQualityDialog(Settings *settings, QWidget *parent) :
    AbstractDialog(parent),
    m_settings(settings),
    m_youtube720Checkbox(new QCheckBox("720P AVC1", this)),
    m_youtube480Checkbox(new QCheckBox("480P FLV", this)),
    m_youtube360Checkbox(new QCheckBox("360P FLV", this)),
    m_youtubeNormalCheckbox(new QCheckBox(tr("Normal") + " AVC1", this)),
    m_dailymotion720Checkbox(new QCheckBox("720P AVC1", this)),
    m_dailymotion480Checkbox(new QCheckBox("480P AVC1", this)),
    m_dailymotionNormalCheckbox(new QCheckBox(tr("Normal") + " AVC1", this)),
    m_vimeo720Checkbox(new QCheckBox("720P H264", this)),
    m_vimeo360Checkbox(new QCheckBox("360P H264", this)),
    m_vimeoMobileCheckbox(new QCheckBox(tr("Mobile"), this)),
    m_buttonBox(new QDialogButtonBox(QDialogButtonBox::Cancel | QDialogButtonBox::Save, Qt::Vertical, this)),
    m_scrollArea(new QScrollArea(this)),
    m_grid(new QGridLayout(this))
{
    this->setWindowTitle(tr("Playback quality"));
    this->setAttribute(Qt::WA_DeleteOnClose, false);

    QWidget *scrollWidget = new QWidget(m_scrollArea);
    QVBoxLayout *vbox = new QVBoxLayout(scrollWidget);

    vbox->addWidget(new SeparatorLabel("YouTube", this));
    vbox->addWidget(m_youtube720Checkbox);
    vbox->addWidget(m_youtube480Checkbox);
    vbox->addWidget(m_youtube360Checkbox);
    vbox->addWidget(m_youtubeNormalCheckbox);
    vbox->addWidget(new SeparatorLabel("Dailymotion", this));
    vbox->addWidget(m_dailymotion720Checkbox);
    vbox->addWidget(m_dailymotion480Checkbox);
    vbox->addWidget(m_dailymotionNormalCheckbox);
    vbox->addWidget(new SeparatorLabel("Vimeo", this));
    vbox->addWidget(m_vimeo720Checkbox);
    vbox->addWidget(m_vimeo360Checkbox);
    vbox->addWidget(m_vimeoMobileCheckbox);

    m_scrollArea->setWidgetResizable(true);
    m_scrollArea->setWidget(scrollWidget);

    this->connect(m_buttonBox, SIGNAL(accepted()), this, SLOT(saveSettings()));
    this->connect(m_buttonBox, SIGNAL(rejected()), this, SLOT(reject()));

    this->loadSettings();
    this->onOrientationChanged();
}

void PlaybackQualityDialog::setLandscapeLayout() {
    this->setFixedHeight(340);
    m_buttonBox->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);

    if (m_grid->isEmpty()) {
        m_grid->addWidget(m_scrollArea, 0, 0);
        m_grid->addWidget(m_buttonBox, 0, 1, Qt::AlignBottom);
    }
    else {
        m_grid->removeWidget(m_buttonBox);
        m_grid->addWidget(m_buttonBox, 0, 1, Qt::AlignBottom);
    }
}

void PlaybackQualityDialog::setPortraitLayout() {
    this->setFixedHeight(600);
    m_buttonBox->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);

    if (m_grid->isEmpty()) {
        m_grid->addWidget(m_scrollArea, 0, 0);
        m_grid->addWidget(m_buttonBox, 1, 0, Qt::AlignBottom);
    }
    else {
        m_grid->removeWidget(m_buttonBox);
        m_grid->addWidget(m_buttonBox, 1, 0, Qt::AlignBottom);
    }
}

void PlaybackQualityDialog::loadSettings() {
    m_youtube720Checkbox->setChecked(m_settings->enableYouTube720Playback());
    m_youtube480Checkbox->setChecked(m_settings->enableYouTube480Playback());
    m_youtube360Checkbox->setChecked(m_settings->enableYouTube360Playback());
    m_youtubeNormalCheckbox->setChecked(true);
    m_youtubeNormalCheckbox->setEnabled(false);
    m_dailymotion720Checkbox->setChecked(m_settings->enableDailymotion720Playback());
    m_dailymotion480Checkbox->setChecked(m_settings->enableDailymotion480Playback());
    m_dailymotionNormalCheckbox->setChecked(true);
    m_dailymotionNormalCheckbox->setEnabled(false);
    m_vimeo720Checkbox->setChecked(m_settings->enableVimeo720Playback());
    m_vimeo360Checkbox->setChecked(m_settings->enableVimeo360Playback());
    m_vimeoMobileCheckbox->setChecked(true);
    m_vimeoMobileCheckbox->setEnabled(false);
}

void PlaybackQualityDialog::saveSettings() {
    m_settings->setEnableYouTube720Playback(m_youtube720Checkbox->isChecked());
    m_settings->setEnableYouTube480Playback(m_youtube480Checkbox->isChecked());
    m_settings->setEnableYouTube360Playback(m_youtube360Checkbox->isChecked());
    m_settings->setEnableDailymotion720Playback(m_dailymotion720Checkbox->isChecked());
    m_settings->setEnableDailymotion480Playback(m_dailymotion480Checkbox->isChecked());
    m_settings->setEnableVimeo720Playback(m_vimeo720Checkbox->isChecked());
    m_settings->setEnableVimeo360Playback(m_vimeo360Checkbox->isChecked());

    this->accept();
}

==> cutetube_1.9.1.tar.gz: cutetube-1.9.1/cutetubeapp/src/maemo5_gui/playbackqualitydialog.cpp <==
#include "playbackqualitydialog.h"
#include "separatorlabel.h"
#include "../base/settings.h"
#include <QCheckBox>
#include <QGridLayout>
#include <QDialogButtonBox>
#include <QScrollArea>

PlaybackFormatDialog::PlaybackFormatDialog(QWidget *parent) :
    AbstractDialog(parent),
    m_youtube720Checkbox(new QCheckBox("720P AVC1", this)),
    m_youtube480Checkbox(new QCheckBox("480P FLV", this)),
    m_youtube360Checkbox(new QCheckBox("360P FLV", this)),
    m_youtubeNormalCheckbox(new QCheckBox(tr("Normal") + " AVC1", this)),
    m_dailymotion720Checkbox(new QCheckBox("720P AVC1", this)),
    m_dailymotion480Checkbox(new QCheckBox("480P AVC1", this)),
    m_dailymotionNormalCheckbox(new QCheckBox(tr("Normal") + " AVC1", this)),
    m_vimeo720Checkbox(new QCheckBox("720P H264", this)),
    m_vimeo360Checkbox(new QCheckBox("360P H264", this)),
    m_vimeoMobileCheckbox(new QCheckBox(tr("Mobile"), this)),
    m_buttonBox(new QDialogButtonBox(QDialogButtonBox::Cancel | QDialogButtonBox::Save, Qt::Vertical, this)),
    m_scrollArea(new QScrollArea(this)),
    m_grid(new QGridLayout(this))
{
    this->setWindowTitle(tr("Playback quality"));
    this->setAttribute(Qt::WA_DeleteOnClose, false);

    QWidget *scrollWidget = new QWidget(m_scrollArea);
    QVBoxLayout *vbox = new QVBoxLayout(scrollWidget);

    vbox->addWidget(new SeparatorLabel("YouTube", this));
    vbox->addWidget(m_youtube720Checkbox);
    vbox->addWidget(m_youtube480Checkbox);
    vbox->addWidget(m_youtube360Checkbox);
    vbox->addWidget(m_youtubeNormalCheckbox);
    vbox->addWidget(new SeparatorLabel("Dailymotion", this));
    vbox->addWidget(m_dailymotion720Checkbox);
    vbox->addWidget(m_dailymotion480Checkbox);
    vbox->addWidget(m_dailymotionNormalCheckbox);
    vbox->addWidget(new SeparatorLabel("Vimeo", this));
    vbox->addWidget(m_vimeo720Checkbox);
    vbox->addWidget(m_vimeo360Checkbox);
    vbox->addWidget(m_vimeoMobileCheckbox);

    m_scrollArea->setWidgetResizable(true);
    m_scrollArea->setWidget(scrollWidget);

    this->connect(m_buttonBox, SIGNAL(accepted()), this, SLOT(saveSettings()));
    this->connect(m_buttonBox, SIGNAL(rejected()), this, SLOT(reject()));

    this->loadSettings();
    this->onOrientationChanged();
}

void PlaybackFormatDialog::setLandscapeLayout() {
    this->setFixedHeight(340);
    m_buttonBox->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);

    if (m_grid->isEmpty()) {
        m_grid->addWidget(m_scrollArea, 0, 0);
        m_grid->addWidget(m_buttonBox, 0, 1, Qt::AlignBottom);
    }
    else {
        m_grid->removeWidget(m_buttonBox);
        m_grid->addWidget(m_buttonBox, 0, 1, Qt::AlignBottom);
    }
}

void PlaybackFormatDialog::setPortraitLayout() {
    this->setFixedHeight(600);
    m_buttonBox->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);

    if (m_grid->isEmpty()) {
        m_grid->addWidget(m_scrollArea, 0, 0);
        m_grid->addWidget(m_buttonBox, 1, 0, Qt::AlignBottom);
    }
    else {
        m_grid->removeWidget(m_buttonBox);
        m_grid->addWidget(m_buttonBox, 1, 0, Qt::AlignBottom);
    }
}

void PlaybackFormatDialog::loadSettings() {
    m_youtube720Checkbox->setChecked(Settings::instance()->enableYouTube720Playback());
    m_youtube480Checkbox->setChecked(Settings::instance()->enableYouTube480Playback());
    m_youtube360Checkbox->setChecked(Settings::instance()->enableYouTube360Playback());
    m_youtubeNormalCheckbox->setChecked(true);
    m_youtubeNormalCheckbox->setEnabled(false);
    m_dailymotion720Checkbox->setChecked(Settings::instance()->enableDailymotion720Playback());
    m_dailymotion480Checkbox->setChecked(Settings::instance()->enableDailymotion480Playback());
    m_dailymotionNormalCheckbox->setChecked(true);
    m_dailymotionNormalCheckbox->setEnabled(false);
    m_vimeo720Checkbox->setChecked(Settings::instance()->enableVimeo720Playback());
    m_vimeo360Checkbox->setChecked(Settings::instance()->enableVimeo360Playback());
    m_vimeoMobileCheckbox->setChecked(true);
    m_vimeoMobileCheckbox->setEnabled(false);
}

void PlaybackFormatDialog::saveSettings() {
    Settings::instance()->setEnableYouTube720Playback(m_youtube720Checkbox->isChecked());
    Settings::instance()->setEnableYouTube480Playback(m_youtube480Checkbox->isChecked());
    Settings::instance()->setEnableYouTube360Playback(m_youtube360Checkbox->isChecked());
    Settings::instance()->setEnableDailymotion720Playback(m_dailymotion720Checkbox->isChecked());
    Settings::instance()->setEnableDailymotion480Playback(m_dailymotion480Checkbox->isChecked());
    Settings::instance()->setEnableVimeo720Playback(m_vimeo720Checkbox->isChecked());
    Settings::instance()->setEnableVimeo360Playback(m_vimeo360Checkbox->isChecked());

    this->accept();
}
